<?php

/**
 * This template is loaded instead of the ticket selector template when a user is signed
 * in but we don't have a valid email from them. i.e. if their email is the default CAS
 * suffix, we ask them to complete their profile
 *
 * @since 1.0.0
 *
 * @param (array) $template_args - The template args passed to this template including an event object
 * @return null
 */

// 108 is the ID for the question group
$additional_form_fields = UBC_CTLT_EE_Mods::get_ubc_reg_form_fields_by_question_group_id( 108 );

// We may get to this page with query vars for an error(s)
$notice = get_query_var( 'ubc_ctlt_notices', '' );
$notices_map = UBC_CTLT_EE_Mods::$ubc_ctlt_notices_map;

// We close off the existing form otherwise it thinks it's a ticket submission.
?>

</form>

<?php if ( $notice && ! empty( $notice ) ) : ?>

<div class="highlight-message error">
	<h3 class="profile-information-required ee-event-h3">
		<span class="dashicons dashicons-no"></span>
		Error
	</h3>
	<?php echo wp_kses_post( $notices_map[ $notice ] ); ?>
</div>

<?php endif; ?>

<div class="we-need-your-email highlight-message important">

	<h3 class="profile-information-required ee-event-h3">
		<span class="dashicons dashicons-lock"></span>
		Profile Information Required
	</h3>

	<p>Thank you for creating an account on the CTLT Events Website. In order to register yourself for events, <strong>we need some more information from you</strong>.</p>

	<p>Completing this form will allow you to register for events and the information you provide here will automatically display when you register for events. You will be able to <a href="<?php echo admin_url( 'profile.php' ); ?>" title="Edit your WordPress profile">edit this information at any time from your profile</a>.</p>

	<form action="" method="post" id="ubc-ctlt-profile-field-needed">

		<div class="default-fields email-first-last-name">

			<div class="uc-ctlt-profile-field">
				<label id="user_email" for="user_email">Email <span class="hint">(Ensure this is valid)</span></label>
				<input aria-required="true" required type="email" id="user_email" name="user_email" class="user_email" placeholder="your.name@ubc.ca" value="" />
			</div>

			<div class="uc-ctlt-profile-field">
				<label id="user_fname" for="user_fname">First Name</label>
				<input aria-required="true" required type="text" id="user_fname" name="user_fname" class="user_fname" placeholder="Alex" value="" />
			</div>

			<div class="uc-ctlt-profile-field">
				<label id="user_lname" for="user_lname">Last Name</label>
				<input aria-required="true" required type="text" id="user_lname" name="user_lname" class="user_lname" value="" placeholder="Smith" />
			</div>

		</div>

		<div class="additional-fields fac-dept-inst-attending-as-fields">

			<?php if ( false !== $additional_form_fields ) : ?>
				<?php foreach ( $additional_form_fields as $question_id => $field_details ) : ?>
				<div class="uc-ctlt-profile-field fac-dept-inst-attending-as-field">
					<label id="question_<?php echo absint( $question_id ); ?>" for="question_<?php echo absint( $question_id ); ?>"><?php echo esc_html( $field_details['label'] ); ?></label>
					<select id="question_<?php echo absint( $question_id ); ?>" name="question_<?php echo absint( $question_id ); ?>" aria-required="true" required>
					<?php foreach ( $field_details['options'] as $option_key => $option_value ) : ?>
						<option value="<?php echo esc_html( $option_value ); ?>"><?php echo esc_html( $option_value ); ?></option>
					<?php endforeach; ?>
					</select>
				</div>
				<?php endforeach; ?>
			<?php endif; ?>

		</div>

		<div class="nonces-and-submits">
			<?php wp_nonce_field( 'ubc_ctlt_extra_profile_info', 'ubc_ctlt_extra_profile_info' ); ?>

			<input type="submit" value="Save Profile Information" id="ubc-ctlt-save-profile-info" class="primary button button-large button-primary" />
		</div>

	</form>

</div><!-- .we-need-your-email -->

<?php // we reopen a form element as there's an automatically generated </form> by EE ?>
<form>
